==> fbp-spec-0.6.0.tgz: package/lib/mocha.js <==
'use strict';

//# Run fbp-spec testcases using Mocha as a runner/frontend
//# Intended to allow reuse of Mocha reporters, or
//# to quickly add a couple of fbp-spec cases to a predominantly Mocha-based testsuite
//# See also ./mochacompat.coffee
var Runner, debug, expectation, runSuite, runnerModule, subprocess, testsuite;

runnerModule = require('./runner');

Runner = runnerModule.Runner;

testsuite = require('./testsuite');

expectation = require('./expectation');

subprocess = require('./subprocess');

debug = require('debug')('fbp-spec:mocha');

runSuite = function runSuite(runner, suite) {
  var suiteDescribe;
  suiteDescribe = suite.skip ? describe.skip : describe;
  return suiteDescribe('' + suite.name, function () {
    beforeEach(function (done) {
      if (suite.timeout != null) {
        this.timeout(suite.timeout);
      }
      return runner.setupSuite(suite, done);
    });
    afterEach(function (done) {
      return runner.teardownSuite(suite, done);
    });
    return suite.cases.forEach(function (testcase) {
      var caseDescribe;
      caseDescribe = testcase.skip ? describe.skip : describe;
      return caseDescribe(testcase.name, function () {
        return it(testcase.assertion, function (done) {
          if (suite.timeout != null) {
            this.timeout(suite.timeout);
          }
          if (testcase.timeout != null) {
            this.timeout(testcase.timeout);
          }
          return runnerModule.runTestAndCheck(runner, testcase, function (err, result) {
            if (err) {
              return done(err);
            }
            return done(result.error);
          });
        });
      });
    });
  });
};

//# run()
// Must be be ran using Mocha,
// it is responsible for setting up the "describe", and "it" functions
exports.run = function (rt, tests, options) {
  var e, i, len, process, results, runner, runnerOptions, start, stop, suite, suites;
  if (options.starttimeout == null) {
    // default pretty high to give time for runtime to start
    options.starttimeout = 5000;
  }
  if (options.fixturetimeout == null) {
    options.fixturetimeout = 2000;
  }
  runnerOptions = {
    connectTimeout: options.starttimeout
  };
  runner = new Runner(rt, runnerOptions);
  try {
    suites = testsuite.getSuitesSync(tests);
  } catch (error) {
    e = error;
    console.log('Unable to get suites:', e);
    throw e;
  }
  process = null;
  start = function start(callback) {
    var subprocessOptions;
    if (!rt.command) {
      return callback(null);
    }
    subprocessOptions = {};
    return process = subprocess.start(rt.command, subprocessOptions, callback);
  };
  stop = function stop(callback) {
    if (process) {
      process.kill();
    }
    return callback(null);
  };
  before(function (done) {
    this.timeout(options.starttimeout + 500);
    start(function (err) {
      debug('started', err);
      expectation.noError(err);
      return runner.connect(done);
    });
    return null;
  });
  after(function (done) {
    stop(function (err) {
      debug('stopped', err);
      expectation.noError(err);
      return runner.disconnect(done);
    });
    return null;
  });
  results = [];
  for (i = 0, len = suites.length; i < len; i++) {
    suite = suites[i];
    if (suite.timeout == null) {
      suite.timeout = options.fixturetimeout;
    }
    results.push(runSuite(runner, suite));
  }
  return results;
};

==> fbp-spec-0.6.7.tgz: package/lib/mocha.js <==
"use strict";

//# Run fbp-spec testcases using Mocha as a runner/frontend
//# Intended to allow reuse of Mocha reporters, or
//# to quickly add a couple of fbp-spec cases to a predominantly Mocha-based testsuite
//# See also ./mochacompat.coffee
var Runner, debug, expectation, runSuite, runnerModule, subprocess, testsuite;
runnerModule = require('./runner');
Runner = runnerModule.Runner;
testsuite = require('./testsuite');
expectation = require('./expectation');
subprocess = require('./subprocess');
debug = require('debug')('fbp-spec:mocha');

runSuite = function runSuite(runner, suite) {
  var suiteDescribe;
  suiteDescribe = suite.skip ? describe.skip : describe;
  return suiteDescribe("".concat(suite.name), function () {
    beforeEach(function (done) {
      if (suite.timeout != null) {
        this.timeout(suite.timeout);
      }

      return runner.setupSuite(suite, done);
    });
    afterEach(function (done) {
      return runner.teardownSuite(suite, done);
    });
    return suite.cases.forEach(function (testcase) {
      var caseDescribe;
      caseDescribe = testcase.skip ? describe.skip : describe;
      return caseDescribe(testcase.name, function () {
        return it(testcase.assertion, function (done) {
          if (suite.timeout != null) {
            this.timeout(suite.timeout);
          }

          if (testcase.timeout != null) {
            this.timeout(testcase.timeout);
          }

          return runnerModule.runTestAndCheck(runner, testcase, function (err, result) {
            if (err) {
              return done(err);
            }

            return done(result.error);
          });
        });
      });
    });
  });
}; //# run()
// Must be be ran using Mocha,
// it is responsible for setting up the "describe", and "it" functions


exports.run = function (rt, tests, options) {
  var e, i, len, process, results, runner, runnerOptions, start, stop, suite, suites;

  if (options.starttimeout == null) {
    // default pretty high to give time for runtime to start
    options.starttimeout = 5000;
  }

  if (options.fixturetimeout == null) {
    options.fixturetimeout = 2000;
  }

  runnerOptions = {
    connectTimeout: options.starttimeout,
    commandTimeout: options.commandtimeout
  };
  runner = new Runner(rt, runnerOptions);

  try {
    suites = testsuite.getSuitesSync(tests);
  } catch (error) {
    e = error;
    console.log('Unable to get suites:', e);
    throw e;
  }

  process = null;

  start = function start(callback) {
    var subprocessOptions;

    if (!rt.command) {
      return callback(null);
    }

    subprocessOptions = {};
    return process = subprocess.start(rt.command, subprocessOptions, callback);
  };

  stop = function stop(callback) {
    if (process) {
      process.kill();
    }

    return callback(null);
  };

  before(function (done) {
    this.timeout(options.starttimeout + 500);
    start(function (err) {
      debug('started', err);
      expectation.noError(err);
      return runner.connect(done);
    });
    return null;
  });
  after(function (done) {
    stop(function (err) {
      debug('stopped', err);
      expectation.noError(err);
      return runner.disconnect(done);
    });
    return null;
  });
  results = [];

  for (i = 0, len = suites.length; i < len; i++) {
    suite = suites[i];

    if (suite.timeout == null) {
      suite.timeout = options.fixturetimeout;
    }

    results.push(runSuite(runner, suite));
  }

  return results;
};
